"""
notation_instances.py
"""

population = [{
    'Name': 'Shlaer-Mellor',
    'About': 'Source of Executable UML / xUML modeling semantics',
    'Why use it': 'Designed for fast easy hand drawing.Great for whiteboards and notes!'
}, {
    'Name': 'Starr',
    'About': 'Stealth mode! Mimimal drawing clutter to put the focus on the subject. Easy to draw online',
    'Why use it': 'Stealth mode! Mimimal drawing clutter to put the focus on the subject. Easy to draw online'
}, {
    'Name': 'xUML',
    'About': 'AKA, Executable UML. Usage of UML to represent executable semantics',
    'Why use it': 'Standards conformance. You are showing diagram to someone who knows, uses or must use UML'
}]
